# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`amazon_ses`](#amazon_ses): Manages postfix to fuly integrate with Amazon SES.
* [`amazon_ses::config`](#amazon_sesconfig): Manages the configuration files for postfix.
* [`amazon_ses::install`](#amazon_sesinstall): Installs postfix
* [`amazon_ses::params`](#amazon_sesparams): Sets OS-specific values
* [`amazon_ses::service`](#amazon_sesservice): Manages the postfix service

## Classes

### amazon_ses

Manages postfix to fuly integrate with Amazon SES.

#### Examples

##### 

```puppet

# Sets up SES for the US EAST region
class { 'amazon_ses':
  domain        => 'test.com',
  smtp_username => 'USERNAME',
  smtp_password => 'PASSWORD',
}

# Sets up SES for the EU region
class { 'amazon_ses':
  domain        => 'test.com',
  smtp_username => 'USERNAME',
  smtp_password => 'PASSWORD',
  ses_region    => 'EU',
}
```

#### Parameters

The following parameters are available in the `amazon_ses` class.

##### `domain`

Data type: `String`

The domain of your web site.  In order to send email through SES servers,
your domain must be verified.
SES Management Console -> Domains -> Verify a New Domain
@see http://docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-domains.html

##### `smtp_username`

Data type: `String`

The username of the smtp user.  Note, this is not your IAM user.
You need to create a unique user for the SES service.
The new user can be created via: SES -> smtp settings -> 'Create My SMTP Credentials' button.

##### `smtp_password`

Data type: `String`

The password of the smtp user.

##### `inet_interfaces`

Data type: `String`

The interfaces to which postfix should bind

Default value: $::amazon_ses::params::default_inet_interfaces

##### `inet_protocols`

Data type: `String`

The protocols postfix should use. 'ipv4', 'ipv6', 'all'.

Default value: $::amazon_ses::params::default_inet_protocols

##### `ses_region`

Data type: `String`

The region of the Amazon smtp server to relay to.
Amazon only offers [3 regions](http://docs.aws.amazon.com/ses/latest/DeveloperGuide/regions.html) with 1 availability zone each.

 * 'US EAST'      - N. Virginia (us-east-1)
 * 'US WEST'      - Oregon (us-west-2)
 * 'EU'           - Ireland (eu-west-1)
 * 'us-east-1'    - uses 'US EAST'
 * 'us-west-1'    - uses 'US WEST'
 * 'us-west-2'    - uses 'US WEST'
 * 'eu-west-1'    - uses 'EU'
 * 'eu-central-1' - uses 'EU'

Default value: $::amazon_ses::params::default_ses_region

##### `smtp_port`

Data type: `Integer`

The port used to connect to the Amazon SMTP server.
The default is 587 as there are no limits. If you use port 25, than you will
need to request that Amazon disables the rate limit (which is 1 email per minute).

Default value: $::amazon_ses::params::default_smtp_port

##### `smtp_tls_ca_file`

Data type: `String`

A file containing CA certificates of root CAs trusted to sign either
remote SMTP server certificates or intermediate CA certificates.
If not specified the OS default location is used.

Default value: $::amazon_ses::params::default_smtp_tls_ca_file

##### `smtpd_tls_cert_file`

Data type: `String`

File with the Postfix SMTP server RSA certificate in PEM format. This
file may also contain the Postfix SMTP server pri vate RSA key.
If not specified the OS default location is used.

Default value: $::amazon_ses::params::default_smtpd_tls_cert_file

##### `smtpd_tls_key_file`

Data type: `String`

File with the Postfix SMTP server RSA private key in PEM format. This
file may be combined with the Postfix SMTP server RSA certificate file
specified with $smtpd_tls_cert_file. The private key must be accessible
without a pass-phrase, i.e. it must not be encrypted.
If not specified the OS default location is used.

Default value: $::amazon_ses::params::default_smtpd_tls_key_file

##### `mynetworks`

Data type: `String`

The mynetworks setting to use for postfix.

Default value: $::amazon_ses::params::default_mynetworks

##### `message_size_limit`

Data type: `Integer`

The maximum size in bytes of a message including envelope information.

Default value: $::amazon_ses::params::default_message_size_limit

##### `smtpd_relay_restrictions`

Data type: `Optional[String]`

Access restrictions for mail relay control.
@see http://www.postfix.org/postconf.5.html#smtpd_relay_restrictions

Default value: `undef`

### amazon_ses::config

Manages the configuration files for postfix.

### amazon_ses::install

Installs postfix

### amazon_ses::params

Sets OS-specific values

### amazon_ses::service

Manages the postfix service

